@@ -29,6 +29,21 @@ class HamelnTensor:
         else:
             return onnx_helper.printable_value_info(self.tensor)
 
+    def __hash__(self):
+        return hash(id(self))
+    
+    def __eq__(self, other):
+        if self.tensor == other.tensor and\
+            self.has_data == other.has_data and\
+            self.node == other.node and\
+            self.is_fake == other.is_fake:
+        
+            return True
+        return False
+    
+    def __ne__(self, other):
+        return not self == other
+    
     def set_node(self, node):
         self.node = node
 
@@ -171,17 +186,17 @@ class HamelnGraph:
 
         # in case that some onnx model inputs contain initializers,
         # we will remove them to avoid rewriting input failure
-
         tmp_inputs = copy.deepcopy(self.graph_input)
+        weight_names = set(i.get_name() for i in self.weight)
         for i in tmp_inputs:
-            if i in self.weight:
+            if i in weight_names:
                 self.graph_input.remove(i)
 
         shape_input = []
         for i in self.node:
             if i.get_op_type() == "Reshape":
                 shape_input.extend(i.input)
-            if i.get_op_type == "Resize" and len(i.input) == 4:
+            if i.get_op_type() == "Resize" and len(i.input) == 4:
                 shape_input.append(i.input[3])
         for i in self.weight:
             if i in shape_input:
